fill_glyph_bounds

Function fill_glyph_bounds 

pub fn fill_glyph_bounds(
    renderer: &mut RenderContext,
    raster_metrics: &RasterMetrics,
)
Fill the glyph’s pixel bounds with the next rotating debug colour. Call before rendering the actual glyph content to visualise the extent.